@@ -1,4 +1,8 @@
-import ujson as json
+try:
+    import ujson as json
+except:
+    import json
+
 import codecs
 
 def loadf(fn,coding='utf8'):
@@ -15,4 +19,4 @@ def dumpf(obj,fn,coding='utf8'):
 load = json.load
 dump = json.dump
 loads = json.loads
-dumps = json.dumps
\ No newline at end of file
+dumps = json.dumps
